==> firebase_repository-1.0.23.tar.gz: lib/src/entities/descarga_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class DescargaEntity extends Equatable {
  final String uuid;
  final double agua;
  final int cabezas;
  final double calcio;
  final String categoriaUuid;
  final String corralUuid;
  final double costo;
  final String dietaUuid;
  final double fdn;
  final DateTime fecha;
  final double fosforo;
  final String cargaUuid;
  final List<dynamic> ingredientes;
  final int kilos;
  final double materiaSeca;
  final double mcal;
  final int meta;
  final int porcentaje;
  final double prot;
  final int remanenteFuturo;
  final int remanenteHoy;
  final String tropaUuid;
  final double talcual;
  final String usuarioUuid;

  DescargaEntity(this.uuid,
      this.agua,
      this.cabezas,
      this.calcio,
      this.categoriaUuid,
      this.corralUuid,
      this.costo,
      this.dietaUuid,
      this.fdn,
      this.fecha,
      this.fosforo,
      this.cargaUuid,
      this.ingredientes,
      this.kilos,
      this.materiaSeca,
      this.mcal,
      this.meta,
      this.porcentaje,
      this.prot,
      this.remanenteFuturo,
      this.remanenteHoy,
      this.tropaUuid,
      this.talcual,
      this.usuarioUuid);

  Map<String, Object> toJson() {
    return {
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforo': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaSeca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }

  Map<String, Object> toMap() {
    return {
      'uuid': this.usuarioUuid,
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforos': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaSeca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }

  DescargaEntity.fromMap(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        agua = data['agua'],
        cabezas = data['cabezas'],
        calcio = data['calcio'],
        categoriaUuid = data['categoriaUuid'],
        corralUuid = data['corralUuid'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        fdn = data['fdn'],
        fecha = data['fecha'],
        fosforo = data['fosforos'],
        cargaUuid = data['cargaUuid'],
        ingredientes = data['ingredientes'],
        kilos =data['kilos'],
        materiaSeca = data['materiaSeca'],
        mcal =data['mcal'],
        meta = data['meta'],
        porcentaje =data['porcentaje'],
        prot =data['prot'],
        remanenteFuturo =data['remanenteFuturo'],
        remanenteHoy = data['remanenteHoy'],
        tropaUuid =data['tropaUuid'],
        talcual = data['talcual'],
        usuarioUuid = data['usuarioUuid'];

  @override
  String toString() {
    return 'DescargaEntity{uuid: $uuid, agua: $agua, cabezas: $cabezas, calcio: $calcio, categoriaUuid: $categoriaUuid, corralUuid: $corralUuid, costo: $costo, dietaUuid: $dietaUuid, fdn: $fdn, fecha: $fecha, fosforo: $fosforo, cargaUuid: $cargaUuid, ingredientes: $ingredientes, kilos: $kilos, materiaSeca: $materiaSeca, mcal: $mcal, meta: $meta, porcentaje: $porcentaje, prot: $prot, remanenteFuturo: $remanenteFuturo, remanenteHoy: $remanenteHoy, tropaUuid: $tropaUuid, talcual: $talcual, usuarioUuid: $usuarioUuid}';
  }

  DescargaEntity.fromJson(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        agua = data['agua'],
        cabezas = data['cabezas'],
        calcio = data['calcio'],
        categoriaUuid = data['categoriaUuid'],
        corralUuid = data['corralUuid'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        fdn = data['fdn'],
        fecha = data['fecha'],
        fosforo = data['fosforos'],
        cargaUuid = data['cargaUuid'],
        ingredientes = data['ingredientes'],
        kilos =data['kilos'],
        materiaSeca = data['materiaSeca'],
        mcal =data['mcal'],
        meta = data['meta'],
        porcentaje =data['porcentaje'],
        prot =data['prot'],
        remanenteFuturo =data['remanenteFuturo'],
        remanenteHoy = data['remanenteHoy'],
        tropaUuid =data['tropaUuid'],
        talcual = data['talcual'],
        usuarioUuid = data['usuarioUuid'];

  DescargaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        agua = double.parse(snapshot.data['agua']),
        cabezas = int.parse(snapshot.data['cabezas'].toString()),
        calcio = double.parse(snapshot.data['calcio'].toString()),
        categoriaUuid = snapshot.data['categoria'],
        corralUuid = snapshot.data['corral'],
        costo = double.parse(snapshot.data['agua'].toString()),
        dietaUuid = snapshot.data['dieta'],
        fdn = double.parse(snapshot.data['fdn']),
        fecha = (snapshot.data['fecha'] is int ||
            snapshot.data['fecha'] is double)
            ? DateTime.fromMillisecondsSinceEpoch(
            snapshot.data['fecha'].round().toInt())
            : snapshot.data['fecha'].toDate(),
        fosforo = double.parse(snapshot.data['dietaUuid'].toString()),
        cargaUuid = snapshot.data['idCarga'],
        ingredientes = snapshot.data['ingredientes'],
        kilos = int.parse(snapshot.data['kilos'].toString()),
        materiaSeca = double.parse(snapshot.data['materiaSeca'].toString()),
        mcal = double.parse(snapshot.data['mcal'].toString()),
        meta = int.parse(snapshot.data['meta'].toString()),
        porcentaje = int.parse(snapshot.data['porcentaje'].toString()),
        prot = double.parse(snapshot.data['prot'].toString()),
        remanenteFuturo = int.parse(snapshot.data['remanenteFuturo']),
        remanenteHoy = int.parse(snapshot.data['remanenteHoy'].toString()),
        tropaUuid = snapshot.data['rodeo'],
        talcual = snapshot.data['talcual'],
        usuarioUuid = snapshot.data['usuario'];

  Map<String, Object> toDocument() {
    return {
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforos': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaSeca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }


}

==> firebase_repository-1.0.34.tar.gz: lib/src/entities/descarga_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class DescargaEntity extends Equatable {
  final String uuid;
  final double agua;
  final int cabezas;
  final double calcio;
  final String categoriaUuid;
  final String corralUuid;
  final double costo;
  final String dietaUuid;
  final double fdn;
  final DateTime fecha;
  final double fosforo;
  final String cargaUuid;
  final List<dynamic> ingredientes;
  final int kilos;
  final double materiaSeca;
  final double mcal;
  final int meta;
  final int porcentaje;
  final double prot;
  final int remanenteFuturo;
  final int remanenteHoy;
  final String tropaUuid;
  final double talcual;
  final String usuarioUuid;

  DescargaEntity(this.uuid,
      this.agua,
      this.cabezas,
      this.calcio,
      this.categoriaUuid,
      this.corralUuid,
      this.costo,
      this.dietaUuid,
      this.fdn,
      this.fecha,
      this.fosforo,
      this.cargaUuid,
      this.ingredientes,
      this.kilos,
      this.materiaSeca,
      this.mcal,
      this.meta,
      this.porcentaje,
      this.prot,
      this.remanenteFuturo,
      this.remanenteHoy,
      this.tropaUuid,
      this.talcual,
      this.usuarioUuid);

  Map<String, Object> toJson() {
    return {
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforo': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaSeca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }

  Map<String, Object> toMap() {
    return {
      'uuid': this.usuarioUuid,
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforos': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaSeca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }

  DescargaEntity.fromMap(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        agua = data['agua'],
        cabezas = data['cabezas'],
        calcio = data['calcio'],
        categoriaUuid = data['categoriaUuid'],
        corralUuid = data['corralUuid'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        fdn = data['fdn'],
        fecha = data['fecha'],
        fosforo = data['fosforos'],
        cargaUuid = data['cargaUuid'],
        ingredientes = data['ingredientes'],
        kilos =data['kilos'],
        materiaSeca = data['materiaSeca'],
        mcal =data['mcal'],
        meta = data['meta'],
        porcentaje =data['porcentaje'],
        prot =data['prot'],
        remanenteFuturo =data['remanenteFuturo'],
        remanenteHoy = data['remanenteHoy'],
        tropaUuid =data['tropaUuid'],
        talcual = data['talcual'],
        usuarioUuid = data['usuarioUuid'];

  @override
  String toString() {
    return 'DescargaEntity{uuid: $uuid, agua: $agua, cabezas: $cabezas, calcio: $calcio, categoriaUuid: $categoriaUuid, corralUuid: $corralUuid, costo: $costo, dietaUuid: $dietaUuid, fdn: $fdn, fecha: $fecha, fosforo: $fosforo, cargaUuid: $cargaUuid, ingredientes: $ingredientes, kilos: $kilos, materiaSeca: $materiaSeca, mcal: $mcal, meta: $meta, porcentaje: $porcentaje, prot: $prot, remanenteFuturo: $remanenteFuturo, remanenteHoy: $remanenteHoy, tropaUuid: $tropaUuid, talcual: $talcual, usuarioUuid: $usuarioUuid}';
  }

  DescargaEntity.fromJson(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        agua = data['agua'],
        cabezas = data['cabezas'],
        calcio = data['calcio'],
        categoriaUuid = data['categoriaUuid'],
        corralUuid = data['corralUuid'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        fdn = data['fdn'],
        fecha = data['fecha'],
        fosforo = data['fosforos'],
        cargaUuid = data['cargaUuid'],
        ingredientes = data['ingredientes'],
        kilos =data['kilos'],
        materiaSeca = data['materiaSeca'],
        mcal =data['mcal'],
        meta = data['meta'],
        porcentaje =data['porcentaje'],
        prot =data['prot'],
        remanenteFuturo =data['remanenteFuturo'],
        remanenteHoy = data['remanenteHoy'],
        tropaUuid =data['tropaUuid'],
        talcual = data['talcual'],
        usuarioUuid = data['usuarioUuid'];

  DescargaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        agua = double.parse(snapshot.data['agua'].toString()),
        cabezas = snapshot.data['cabezas'].toInt(),
        calcio = double.parse(snapshot.data['calcio'].toString()),
        categoriaUuid = snapshot.data['categoria'],
        corralUuid = snapshot.data['corral'],
        costo = double.parse(snapshot.data['costo'].toString()),
        dietaUuid = snapshot.data['dieta'],
        fdn = double.parse(snapshot.data['fdn'].toString()),
        fecha = (snapshot.data['fecha'] is int ||
            snapshot.data['fecha'] is double)
            ? DateTime.fromMillisecondsSinceEpoch(
            snapshot.data['fecha'].round().toInt())
            : snapshot.data['fecha'].toDate(),
        fosforo = double.parse(snapshot.data['fosforo'].toString()),
        cargaUuid = snapshot.data['idCarga'],
        ingredientes = snapshot.data['ingredientes'],
        kilos = snapshot.data['kilos'].toInt(),
        materiaSeca = double.parse(snapshot.data['materiaseca'].toString()),
        mcal = double.parse(snapshot.data['mcal'].toString()),
        meta = snapshot.data['meta'].toInt(),
        porcentaje = snapshot.data['porcentaje'].toInt(),
        prot = double.parse(snapshot.data['prot'].toString()),
        remanenteFuturo = snapshot.data['remanentefuturo'].toInt(),
        remanenteHoy = snapshot.data['remanentehoy'].toInt(),
        tropaUuid = snapshot.data['rodeo'],
        talcual = snapshot.data['talcual'],
        usuarioUuid = snapshot.data['usuario'];

  Map<String, Object> toDocument() {
    return {
      'agua': this.agua,
      'cabezas': this.cabezas,
      'calcio': this.calcio,
      'categoriaUuid': this.categoriaUuid,
      'corralUuid': this.corralUuid,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforos': this.fosforo,
      'cargaUuid': this.cargaUuid,
      'ingredientes': this.ingredientes,
      'kilos': this.kilos,
      'materiaseca': this.materiaSeca,
      'mcal': this.mcal,
      'meta': this.meta,
      'porcentaje': this.porcentaje,
      'prot': this.prot,
      'remanenteFuturo': this.remanenteFuturo,
      'remanenteHoy': this.remanenteHoy,
      'tropaUuid': this.tropaUuid,
      'talcual': this.talcual,
      'usuarioUuid': this.usuarioUuid
    };
  }


}
